@@ -17,7 +17,8 @@ def upsert(engine,
            add_new_columns=False,
            adapt_dtype_of_empty_db_columns=False,
            chunksize=10000,
-           dtype=None):
+           dtype=None,
+           yield_chunks=False):
     """
     Insert updates/ignores a pandas DataFrame into a SQL table (or
     creates a SQL table from the DataFrame if it does not exist).
@@ -90,6 +91,10 @@ def upsert(engine,
         Similar to pd.to_sql dtype argument.
         This is especially useful for MySQL where the length of
         primary keys with text has to be provided (see Examples)
+    yield_chunks : bool, default False
+        If True gives back an sqlalchemy object
+        (sqlalchemy.engine.cursor.LegacyCursorResult)
+        at each chunk with which you can for instance count rows.
 
     Examples
     --------
@@ -178,6 +183,35 @@ def upsert(engine,
     | John Travolta         | True          | 2020-04-04 00:00:00.000000 |             1.88 |
     | Arnold Schwarzenegger | True          |                            |             1.88 |
     | John Cena             | True          |                            |             1.84 |
+
+    #### 2. Example for getting information on upserted chunks (parameter `yield_chunks` == True)
+    >>> import pandas as pd
+    >>> from pangres import upsert, DocsExampleTable
+    >>> from sqlalchemy import create_engine, VARCHAR
+    >>>
+    >>> # config
+    >>> engine = create_engine("sqlite:///:memory:")
+    >>> chunksize = 2
+    >>>
+    >>> # get a DataFrame from somwhere
+    >>> df = DocsExampleTable.df
+    >>> print(df.to_markdown())
+    | full_name     | likes_sport   | updated                   |   size_in_meters |
+    |:--------------|:--------------|:--------------------------|-----------------:|
+    | John Rambo    | True          | 2020-02-01 00:00:00+00:00 |             1.77 |
+    | The Rock      | True          | 2020-04-01 00:00:00+00:00 |             1.96 |
+    | John Travolta | False         | NaT                       |           nan    |
+
+    >>>
+    >>> # upsert in chunks of size `chunksize` and get
+    >>> # back the number of rows updated for each chunk
+    >>> iterator = upsert(engine=engine, df=df, table_name='test_row_count',
+    ...                   chunksize=chunksize, if_row_exists='update',
+    ...                   yield_chunks=True)
+    >>> for result in iterator:
+    ...     print(f'{result.rowcount} row(s) updated')
+    2 row(s) updated
+    1 row(s) updated
     """
     pse = PandasSpecialEngine(engine=engine,
                               df=df,
@@ -196,9 +230,11 @@ def upsert(engine,
     if create_schema and schema is not None:
         pse.create_schema_if_not_exists()
     pse.create_table_if_not_exists()
-    
+
     # stop if no rows
     ## note: use simple check with len() as df.empty returns True if there are index values but no columns
     if len(df) == 0:
         return
-    pse.upsert(if_row_exists=if_row_exists, chunksize=chunksize)
+
+    # returns an iterator when we yield chunks otherwise None
+    return pse.upsert(if_row_exists=if_row_exists, chunksize=chunksize, yield_chunks=yield_chunks)
